import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:zhiying_base_widget/pages/setting_page/models/setting_page_style_item_model.dart';
import 'package:zhiying_base_widget/pages/setting_page/models/setting_page_style_model.dart';
import 'package:zhiying_base_widget/pages/setting_page/setting_page_bloc.dart';
import 'package:zhiying_comm/util/base_bloc.dart';
import 'package:zhiying_comm/zhiying_comm.dart';

class SettingPage extends StatefulWidget {
  final Map<String, dynamic> data;

  const SettingPage(this.data, {Key key}) : super(key: key);

  @override
  _SettingPageState createState() => _SettingPageState();
}

class _SettingPageState extends State<SettingPage> {
  @override
  Widget build(BuildContext context) {
    return BlocProvider<SettingPageBloc>(
      bloc: SettingPageBloc(),
      child: _SettingContainer(widget.data),
    );
  }
}

class _SettingContainer extends StatefulWidget {
  final Map<String, dynamic> data;

  const _SettingContainer(
    this.data, {
    Key key,
  }) : super(key: key);

  @override
  _SettingContainerState createState() => _SettingContainerState();
}

class _SettingContainerState extends State<_SettingContainer> {
  SettingPageBloc _bloc;

  @override
  void initState() {
    _bloc = BlocProvider.of<SettingPageBloc>(context);
    _bloc.loadData(widget.data['skip_identifier']);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return StreamBuilder<SettingPageStyleModel>(
        stream: _bloc.outData,
        builder: (BuildContext context, AsyncSnapshot snapshot) {
          SettingPageStyleModel style = snapshot.data;
          return Scaffold(
              backgroundColor: Color(0xfff9f9f9),
              appBar: _createNav(style),
              body: SingleChildScrollView(
                child: Column(
                  children: style?.settings?.map((list) {
                        return _createSection(list);
                      })?.toList() ??
                      [],
                ),
              ));
        });
  }

  // 导航栏
  Widget _createNav(SettingPageStyleModel style) {
    return CupertinoNavigationBar(
      border: Border(
        bottom: BorderSide(
          width: 0.0, // One physical pixel.
          style: BorderStyle.none,
        ),
      ),
      backgroundColor: HexColor.fromHex(style?.appBarBgColor ?? 'ffffff'),
      leading: Navigator.canPop(context)
          ? GestureDetector(
              child: Container(
                padding: EdgeInsets.zero,
                child: Icon(
                  Icons.arrow_back_ios,
                  size: 20,
                ),
              ),
              onTap: () {
                if (Navigator.canPop(context)) {
                  Navigator.pop(context);
                }
              },
            )
          : Container(),
      middle: Text(
        style?.appBarName ?? '设置',
        style: TextStyle(
          fontSize: 15,
          color: HexColor.fromHex(style?.appBarNameColor ?? '333333'),
        ),
      ),
    );
  }

  Widget _createSection(List<SettingPageStyleItemModel> sections) {
    return Container(
      margin: EdgeInsets.only(top: 8),
      child: Column(
        children: sections.map((item) {
          return _createItem(item);
        }).toList(),
      ),
    );
  }

  Widget _createItem(SettingPageStyleItemModel item) {
    return Container(
      width: double.infinity,
      height: 50,
      color: Colors.white,
      child: Row(
        children: <Widget>[Text(item.name), Text('aaaaa')],
      ),
    );
  }
}
